@@ -27,6 +27,7 @@ class PathValues(str, enum.Enum):
     ACCOUNTS_ACCOUNT_ID_ORDERS = "/accounts/{accountId}/orders"
     ACCOUNTS_ACCOUNT_ID_RECENT_ORDERS = "/accounts/{accountId}/recentOrders"
     ACCOUNTS_ACCOUNT_ID_RETURN_RATES = "/accounts/{accountId}/returnRates"
+    ACCOUNTS_ACCOUNT_ID_ACTIVITIES = "/accounts/{accountId}/activities"
     ACCOUNTS_ACCOUNT_ID_OPTIONS = "/accounts/{accountId}/options"
     ACCOUNTS_ACCOUNT_ID_OPTIONS_CHAIN = "/accounts/{accountId}/optionsChain"
     ACCOUNTS_ACCOUNT_ID_OPTION_STRATEGY = "/accounts/{accountId}/optionStrategy"
@@ -39,6 +40,13 @@ class PathValues(str, enum.Enum):
     TRADE_TRADE_ID = "/trade/{tradeId}"
     TRADE_PLACE = "/trade/place"
     ACCOUNTS_ACCOUNT_ID_ORDERS_CANCEL = "/accounts/{accountId}/orders/cancel"
+    ACCOUNTS_ACCOUNT_ID_TRADING_BRACKET = "/accounts/{accountId}/trading/bracket"
+    ACCOUNTS_ACCOUNT_ID_TRADING_SIMPLE_BROKERAGE_ORDER_ID_REPLACE = "/accounts/{accountId}/trading/simple/{brokerageOrderId}/replace"
+    ACCOUNTS_ACCOUNT_ID_TRADING_SIMPLE = "/accounts/{accountId}/trading/simple"
+    ACCOUNTS_ACCOUNT_ID_TRADING_SIMPLE_BROKERAGE_ORDER_ID_CANCEL = "/accounts/{accountId}/trading/simple/{brokerageOrderId}/cancel"
+    ACCOUNTS_ACCOUNT_ID_TRADING_SIMPLE_PREVIEW = "/accounts/{accountId}/trading/simple/preview"
+    ACCOUNTS_ACCOUNT_ID_TRADING_INSTRUMENTS_CRYPTOCURRENCY_PAIRS = "/accounts/{accountId}/trading/instruments/cryptocurrencyPairs"
+    ACCOUNTS_ACCOUNT_ID_TRADING_INSTRUMENTS_CRYPTOCURRENCY_PAIRS_INSTRUMENT_SYMBOL_QUOTE = "/accounts/{accountId}/trading/instruments/cryptocurrencyPairs/{instrumentSymbol}/quote"
     SNAP_TRADE_PARTNERS = "/snapTrade/partners"
     ACCOUNTS_ACCOUNT_ID_SYMBOLS = "/accounts/{accountId}/symbols"
     BROKERAGES = "/brokerages"
